@@ -94,9 +94,9 @@ def process_imu(sessiondata, camber=15, wsize=0.31, wbase=0.60, inplace=False):
     frame["gyro_cor"] = (right["gyro_cor"] + left["gyro_cor"]) / 2
 
     # Calculation of rotations, rotational velocity and acceleration
-    frame["rot_vel"] = lowpass_butter(-frame["gyroscope_z"], sfreq=sfreq, cutoff=4)
+    frame["rot_vel"] = lowpass_butter(frame["gyroscope_z"], sfreq=sfreq, cutoff=20)
     frame["rot"] = cumtrapz(abs(frame["rot_vel"]) / sfreq, initial=0.0)
-    frame["rot_acc"] = np.gradient(frame["rot_vel"]) * sfreq
+    frame["rot_acc"] = lowpass_butter(np.gradient(frame["rot_vel"]) * sfreq, sfreq=sfreq, cutoff=20)
 
     # Calculation of speed, acceleration and distance
     right["vel"] = right["gyro_cor"] * wsize * deg2rad  # angular velocity to linear velocity
@@ -106,8 +106,8 @@ def process_imu(sessiondata, camber=15, wsize=0.31, wbase=0.60, inplace=False):
     left["dist"] = cumtrapz(left["vel"] / sfreq, initial=0.0)
 
     frame["vel"] = (right["vel"] + left["vel"]) / 2  # mean velocity both sides
-    frame["vel"] = lowpass_butter(frame["vel"], sfreq=sfreq, cutoff=10)
-    frame["acc"] = lowpass_butter(np.gradient(frame["vel"])*sfreq, sfreq=sfreq, cutoff=10) #mean acceleration from velocity
+    frame["vel"] = lowpass_butter(frame["vel"], sfreq=sfreq, cutoff=20)
+    frame["acc"] = lowpass_butter(np.gradient(frame["vel"])*sfreq, sfreq=sfreq, cutoff=20) #mean acceleration from velocity
     frame["dist"] = (right["dist"] + left["dist"]) / 2  # mean distance
     frame["accelerometer_x"] = frame["accelerometer_x"]*9.81
 
@@ -139,7 +139,7 @@ def process_imu(sessiondata, camber=15, wsize=0.31, wbase=0.60, inplace=False):
     comb_ratio = lowpass_butter(comb_ratio, sfreq=sfreq, cutoff=20)  # Filter the signal
     comb_ratio = np.clip(comb_ratio, 0, 1)  # clamp Combratio values, not in df
     frame["skid_vel"] = (frame["skid_vel_right"] * comb_ratio) + (frame["skid_vel_left"] * (1 - comb_ratio))
-    frame["skid_vel"] = lowpass_butter(frame["skid_vel"], sfreq=sfreq, cutoff=10)
+    frame["skid_vel"] = lowpass_butter(frame["skid_vel"], sfreq=sfreq, cutoff=20)
     frame["skid_dist"] = cumtrapz(frame["skid_vel"], initial=0.0) / sfreq  # Combined skid distance
     return sessiondata
 
@@ -196,10 +196,10 @@ def push_imu(acceleration: np.array, sfreq=400.):
     max_freq = f[min_freq_f + max_freq_ind_temp]
     max_freq = min(max_freq, 3.)
     cutoff_freq = 1.5 * max_freq
-    frame_acceleration_p = lowpass_butter(acceleration, sfreq=sfreq, cutoff=cutoff_freq)
-    std_fr_acc = np.std(frame_acceleration_p)
-    push_idx, push_acc_fr_ind = find_peaks(frame_acceleration_p, height=std_fr_acc / 2,
-                                              distance=round(1 / (max_freq * 1.5) * sfreq), prominence=std_fr_acc / 2)
+    acc_filt = lowpass_butter(acceleration, sfreq=sfreq, cutoff=cutoff_freq)
+    std_acc = np.std(acc_filt)
+    push_idx, peak_char = find_peaks(acc_filt, height=std_acc / 2,
+                                              distance=round(1 / (max_freq * 1.5) * sfreq), prominence=std_acc / 2)
     n_pushes = len(push_idx)
     push_freq = n_pushes / (len(acceleration) / sfreq)
     cycle_time = pd.DataFrame([])
@@ -207,7 +207,7 @@ def push_imu(acceleration: np.array, sfreq=400.):
     for n in range(0, len(push_idx) - 1):
         cycle_time = cycle_time.append([(push_idx[n + 1] / sfreq) - (push_idx[n] / sfreq)])
 
-    return push_idx, frame_acceleration_p, n_pushes, cycle_time, push_freq
+    return push_idx, acc_filt, n_pushes, cycle_time, push_freq
 
 
 def vel_zones(velocity, time):
